@@ -135,8 +135,11 @@ module Vim
       if override_lines.empty?
         FileUtils.rm override_file if File.exist? override_file
       elsif override_lines.hash != checksum
+        FileUtils.mkdir_p(File.dirname(override_file))
         File.open(override_file, 'w') do |file|
-          file.write override_lines
+          override_lines.each do |line|
+            file.write line
+          end
         end
       end
     end
