@@ -30,4 +30,23 @@ describe Vim::AddonManager do
     target_dir.should have_file('vam/newstylemigrated/syntax/newstylemigrated.vim')
   end
 
+  it 'disables addons' do
+    addon_list = addons('foo')
+    addon_manager.install(addon_list)
+    addon_manager.disable(addon_list)
+
+    output = File.readlines(override_file).map(&:strip)
+    output.should include(addon_list.first.disabled_by_line)
+  end
+
+  it 're-enables addons' do
+    addon_list = addons('foo')
+    addon_manager.install(addon_list)
+    addon_manager.disable(addon_list)
+    File.exists?(override_file).should be_true
+
+    addon_manager.enable(addon_list)
+    File.exists?(override_file).should be_false
+  end
+
 end
